@@ -17,7 +17,7 @@ Net::Blogger::Engine::Base - base class for Blogger API engines
 
     my $self = {};
     bless $self,$pkg;
-    
+
     $self->SUPER::init(@_);
     return $self;
  }
@@ -26,9 +26,12 @@ Net::Blogger::Engine::Base - base class for Blogger API engines
 
 Base.pm is used a base class by implementation specific modules for the Blogger API.
 
-If an implementation follows the Blogger API to the letter then, conceivably, all it's package would need to define is a constructor and I<Proxy> method to define the URI of it's XML-RPC server.
+If an implementation follows the Blogger API to the letter then, conceivably, all 
+it's package would need to define is a constructor and I<Proxy> method to define the 
+URI of it's XML-RPC server.
 
-Base.pm inherits the functionality of Net::Blogger::Base::API and Net::Blogger::Base::Ext and defines private methods used by each.
+Base.pm inherits the functionality of Net::Blogger::Base::API and Net::Blogger::Base::Ext 
+and defines private methods used by each.
 
 =cut
 
@@ -37,7 +40,7 @@ use strict;
 
 use vars qw ( $AUTOLOAD );
 
-$Net::Blogger::Engine::Base::VERSION        = '0.2';
+$Net::Blogger::Engine::Base::VERSION        = '0.32';
 @Net::Blogger::Engine::Base::ISA            = qw ( Exporter Net::Blogger::API::Core Net::Blogger::API::Extended );
 @Net::Blogger::Engine::Base::ISA::EXPORT    = qw ();
 @Net::Blogger::Engine::Base::ISA::EXPORT_OK = qw ();
@@ -46,20 +49,22 @@ use Carp;
 use Error;
 use Exporter;
 
-use XMLRPC::Lite;
+use SOAP::Lite;
 
 use Net::Blogger::API::Core;
 use Net::Blogger::API::Extended;
 
-=head1 CONSTRUCTOR METHODS
+=head1 PACKAGE METHODS
 
-=head2 Blogger->new(%args)
+=cut
+
+=head2 __PACKAGE->new(\%args)
 
 Instantiate a new Blogger object.
 
 Valid arguments are :
 
-=over
+=over 4
 
 =item *
 
@@ -87,6 +92,11 @@ String. A valid password for the username/blogid pair.
 
 =back
 
+Releases prior to Net::Blogger 0.85 accepted a list of arguments
+rather than a reference. Version 0.85+ are backwards compatible.
+
+Returns an object. Woot!
+
 =cut
 
 sub new {
@@ -102,7 +112,7 @@ sub new {
 
 sub init {
     my $self = shift;
-    my $args = { @_ };
+    my $args = (ref($_[0]) eq "HASH") ? shift : { @_ };
 
     $self->AppKey($args->{'appkey'});
     $self->Username($args->{'username'});
@@ -112,20 +122,24 @@ sub init {
     $self->{'debug'}   = $args->{'debug'};
     $self->{"_posts"}  = [];
 
+    # Note to self: this is what comments are for.
+    # It's late, I'm hungry, I don't want to have
+    # to remember what I was smoking when I wrote
+    # this...
+
     (my $caller = (caller(2))[3]) =~ /(.*)::([^::]+)::([^::]+)$/;
     $self->{'__parent'} = $2;
 
     return 1;
 }
 
-=head1 PUBLIC METHODS
+=head1 OBJECT METHODS
 
-There are no public methods. See Net::Blogger::Base::API and Net::Blogger::Base::Ext.
+There are no public methods. See I<Net::Blogger::Base::API> and
+I<Net::Blogger::Base::Ext>.
 
 =cut
 
-=pod
-
 =head1 PRIVATE METHODS
 
 =cut
@@ -179,34 +193,48 @@ sub LastError {
     return $e;
 }
 
-=head1 PRIVATE METHODS
-
-=cut
-
-=head2 $pkg->_Client()
-
-Return an XML-RPC client object.
-
-=cut
+sub Transport {
+  return "XMLRPC";
+}
 
 sub _Client {
     my $self = shift;
 
-    if (ref($self->{"_xmlrpc"}) ne "XMLRPC::Lite") {
-      my $client = XMLRPC::Lite->new()
+    unless (ref($self->{"_client"}) =~ /^(XMLRPC|SOAP)::Lite$/) {
+
+      my $pkg = uc $self->Transport();
+
+      if ($pkg =~ /^(XMLRPC|SOAP)$/) {
+	$pkg = join("::",$pkg,"Lite");
+      } 
+
+      else {
+	die "Unknown transport : '$pkg'\n";
+	$self->LastError("Unknown transport : $pkg");
+	return undef;
+      }
+
+      eval "require $pkg";
+
+      if ($@) {
+	die "Failed to eval, $@\n";
+      }
+      my $client = $pkg->new()
 	|| Error->throw(-text=>$!);
 
       $client->on_fault(\&_ClientFault);
       $client->proxy($self->Proxy); 
+      $client->uri($self->Uri());
 
+      # Fix this.
       if ($self->{'debug'}) {
 	$client->on_debug(sub { print @_; });
       }
 
-      $self->{"_xmlrpc"} = $client;
+      $self->{"_client"} = $client;
     }
 
-    return $self->{"_xmlrpc"};
+    return $self->{"_client"};
 }
 
 sub _ClientFault {
@@ -219,19 +247,15 @@ sub _ClientFault {
     return 0; 
 }
 
-=head2 $pkg->_Type(%args)
-
-=cut
-
 sub _Type {
   my $self = shift;
   my $name = shift;
 
   if ($name =~ /^(hash|array)$/) {
-    return XMLRPC::Data->name(args=>@_);
+    return SOAP::Data->name(args=>@_);
   }
 
-  return XMLRPC::Data->type($name,@_);
+  return SOAP::Data->type($name,@_);
 }
 
 sub DESTROY {
@@ -247,7 +271,7 @@ sub AUTOLOAD {
 	return undef;
     }
 
-    unless ($AUTOLOAD =~ /^(Proxy|AppKey|BlogId|Username|Password)$/) {
+    unless ($AUTOLOAD =~ /^(Proxy|Uri|AppKey|BlogId|Username|Password)$/) {
 	$self->LastError("Unkown method '$AUTOLOAD' called. Skipping.");
 	return undef;
     }
@@ -255,32 +279,38 @@ sub AUTOLOAD {
     my $property = lc "_".$AUTOLOAD;
 
     if (my $arg = shift) { 
-	$self->{ $property } = $arg; 
+      $self->{ $property } = $arg; 
+     
+      if ($AUTOLOAD eq "Proxy") {
+	$self->{"_client"} = undef;
+      }
+      
+      #
 
-	if (exists $self->{'__meta'}) {
-	  $self->{'__meta'}->$property($arg);
-	}
-
-	if (exists $self->{'__mt'}) {
-	  $self->{'__mt'}->$property($arg);
-	}
+      if (exists $self->{'__meta'}) {
+	$self->{'__meta'}->$property($arg);
+      }
+      
+      if (exists $self->{'__mt'}) {
+	$self->{'__mt'}->$property($arg);
+      }
+      
+      if (exists $self->{'__slash'}) {
+	$self->{'__slash'}->$property($arg);
+      }
 
     }
    
-    if ($AUTOLOAD eq "Proxy") {
-	$self->{"_xmlrpc"} = undef;
-    }
-
     return $self->{ $property };
 }
 
 =head1 VERSION
 
-0.2
+0.32
 
 =head1 DATE
 
-May 04, 2002
+$Date: 2003/03/05 04:30:42 $
 
 =head1 AUTHOR
 
@@ -294,73 +324,9 @@ L<Net::Blogger::API::Extended>
 
 L<SOAP::Lite>
 
-=head1 CHANGES
-
-=head2 0.2
-
-=over
-
-=item *
-
-Added hooks to set child API (metaWeblog,mt) login data when parent object changes.
-
-=item *
-
-Modified I<_Type> to handle hash references.
-
-=item *
-
-Added quotes to I<$VERSION>
-
-=back
-
-=head2 0.1.3
-
-=over
-
-=item *
-
-Updated POD
-
-=back
-
-=head2 0.1.2
-
-=over
-
-=item * 
-
-Updated POD
-
-=back
-
-=head2 0.1.1
-
-=over
-
-=item *
-
-The XML-RPC client is instantiated and set using a discreet object (rather than via a hash key for the Bloggger.pm object) because the I<XMLRPC::Lite::proxy> method and the I<Net::Blogger::Engine::Base::Proxy> method (which is AUTOLOAD-ed) are getting confused. (WTF?)
-
-=item *
-
-No need to pass I<$self> to I<&_ClientFault>.
-
-=back
-
-=head2 0.1
-
-=over
-
-=item *
-
-Initial revision.
-
-=back
-
 =head1 LICENSE
 
-Copyright (c) 2001-2002 Aaron Straup Cope.
+Copyright (c) 2001-2003 Aaron Straup Cope.
 
 This is free software, you may use it and distribute it under the same terms as Perl itself.
 
